Google Classroom Baseline Report

### Secure Cloud Business Applications (SCuBA)

### Baseline Documents

# Google Classroom Baseline Report

#### Note: Google Classroom is not available by default in GWS but as an additional Google Service.

Customer Name | Customer Domain | Customer ID | Report Date | Baseline Version | Tool Version
--- | --- | --- | --- | --- | ---
Cool Example Org | example.org | ABCDEFG | 06/26/2025 16:02:22 Pacific Daylight Time | 0.5 | v0.5.0

## CLASSROOM-1 Class Membership

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CLASSROOM.1.1v0.5 | Who can join classes in your domain SHALL be set to Users in your domain only. | Pass | Shall | Requirement met in all OUs and groups.
GWS.CLASSROOM.1.2v0.5 | Which classes users in your domain can join SHALL be set to Classes in your domain only. | Pass | Shall | Requirement met in all OUs and groups.

## CLASSROOM-2 Classroom API

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CLASSROOM.2.1v0.5 | Users SHALL NOT be able to authorize apps to access their Google Classroom data. | Pass | Shall | Requirement met in all OUs and groups.

## CLASSROOM-3 Roster Import

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CLASSROOM.3.1v0.5 | Roster import with Clever SHOULD be turned off. | Pass | Should | Requirement met in all OUs and groups.

## CLASSROOM-4 Student Unenrollment

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CLASSROOM.4.1v0.5 | Only teachers SHALL be allowed to unenroll students from classes. | Pass | Shall | Requirement met in all OUs and groups.

## CLASSROOM-5 Class Creation

Control ID | Requirement | Result | Criticality | Details
--- | --- | --- | --- | ---
GWS.CLASSROOM.5.1v0.5 | Class creation SHALL be restricted to verified teachers only. | Pass | Shall | Requirement met in all OUs and groups.